@@ -163,6 +163,17 @@ def test_service(host, name, running, enabled):
     service = host.service(name)
     assert service.is_running == running
     assert service.is_enabled == enabled
+    # check with systemd_properties
+    assert (
+        service.systemd_properties["UnitFileState"] == "enabled"
+        if enabled
+        else "disabled"
+    )
+    assert (
+        service.systemd_properties["ActiveState"] in ["active"]
+        if running
+        else ["failed", "inactive"]
+    )
 
 
 def test_salt(host):
@@ -666,3 +677,26 @@ def test_addr_namespace(host):
     with pytest.raises(NotImplementedError):
         # nc is not available so an error is raised
         assert not namespace_lookup.port("443").is_reachable
+
+
+@pytest.mark.parametrize(
+    "family",
+    ["inet", None],
+)
+def test_interface(host, family):
+    # exist
+    assert host.interface("eth0", family=family).exists
+    assert not host.interface("does_not_exist", family=family).exists
+    # adresses
+    addresses = host.interface.default(family).addresses
+    assert len(addresses) > 0
+    for add in addresses:
+        try:
+            ip_address(add)
+        except ValueError:
+            pytest.fail(f"{add} is not a valid IP address")
+    # names and default
+    assert "eth0" in host.interface.names()
+    default_itf = host.interface.default(family)
+    assert default_itf.name == "eth0"
+    assert default_itf.exists
